import gtk
import gtk.glade

# The new task assistant's class.
class PyAtCronNewTask:

	def __init__ (self, parent):

		# This is the current page.
		self.currentPage = 1

		# This is the last page.
		self.lastPage = 1

		# This is the previously displayed page
		self.oldPage = None

		# We load the widgets and the callbacks from the glade file.
		self.widgetTree = gtk.glade.XML ("newtask.glade")
		dic = {
						"on_newtask_delete_event" : self.deleteEvent,
						"on_cancel_button_clicked" : self.cancelClicked,
						"on_back_button_clicked" : self.backClicked,
						"on_forward_button_clicked" : self.forwardClicked
					}
		self.widgetTree.signal_autoconnect (dic)

		# It's the base widget.
		self.win = self.widgetTree.get_widget ("newtask")

		# If a parent is specified, center the window on it.
		if parent:
			self.win.set_transient_for (parent)
			self.win.set_position (gtk.WIN_POS_CENTER_ON_PARENT)

		# Sets the color of the bars.
		frameBackground = gtk.gdk.color_parse ("#4464AC")
		mainBackground = gtk.gdk.color_parse ("#FFFFFF")

		self.widgetTree.get_widget ("titlebar").modify_bg (gtk.STATE_NORMAL, frameBackground)
		self.widgetTree.get_widget ("topbar").modify_bg (gtk.STATE_NORMAL, frameBackground)
		self.widgetTree.get_widget ("bottombar").modify_bg (gtk.STATE_NORMAL, frameBackground)
		self.widgetTree.get_widget ("leftbar").modify_bg (gtk.STATE_NORMAL, frameBackground)
		self.widgetTree.get_widget ("rightbar").modify_bg (gtk.STATE_NORMAL, frameBackground)
		self.widgetTree.get_widget ("mainbar").modify_bg (gtk.STATE_NORMAL, mainBackground)

		# We define 3 pages. Each page is a label.
		pageWidget1 = gtk.Label ("This is page 1")
		pageWidget1.set_alignment (0.0, 0.0)

		pageWidget2 = gtk.Label ("This is page 2")
		pageWidget2.set_alignment (0.0, 0.0)

		pageWidget3 = gtk.Label ("This is page 3")
		pageWidget3.set_alignment (0.0, 0.0)

		self.pages = {
		               1 : {
                         "title" : "Page 1",
                         "widget" : pageWidget1
                       },
		               2 : {
                         "title" : "Page 2",
                         "widget" : pageWidget2
                       },
		               3 : {
                         "title" : "Page 3",
                         "widget" : pageWidget3
                       }
		             }
		self.lastPage = 3

		# Displays the assistant.
		self.win.show ()

		# Update the currently viewed page
		self.updatePage ()

	def deleteEvent (self, obj, event):
		self.quit ()

	def backClicked (self, obj):
		self.goBack ()

	def forwardClicked (self, obj):
		self.goForward ()

	def cancelClicked (self, obj):
		self.quit ()

	def goBack (self):
		# If we're not on the first page, go back
		if (self.currentPage > 1):
			print "TODO: go back"
			self.currentPage = self.currentPage - 1
			self.updatePage ()

	def goForward (self):
		# If we're not on the last page, go forward. Else, finish with the assistant.
		if (self.currentPage < self.lastPage):
			print "TODO: go forward"
			self.currentPage = self.currentPage + 1
			self.updatePage ()
		else:
			print "TODO: finish"
			self.quit ()

	def updatePage (self):
		# If we are of the first page, make the back button insensitive.
		self.widgetTree.get_widget ("back_button").set_sensitive (self.currentPage != 1)

		# If we are of the last page, the button's text to "OK". Else, it's "Forward".
		self.widgetTree.get_widget ("forward_button").set_use_stock (True)
		if (self.currentPage == self.lastPage):
			self.widgetTree.get_widget ("forward_button").set_label (eval('gtk.STOCK_OK'))
		else:
			self.widgetTree.get_widget ("forward_button").set_label (eval('gtk.STOCK_GO_FORWARD'))

		# If we currently have a page displayed, remove it.
		if (self.oldPage != None):
			self.widgetTree.get_widget ("mainbar").remove (self.oldPage)

		# Set the assistant's title.
		title = '<span size="xx-large" color="white">' + self.pages [self.currentPage]["title"] + '</span>'
		self.widgetTree.get_widget ("title").set_markup (title)

		# Add the current page to the dialog (with a 4 pixels padding), and display it.
		page = self.pages [self.currentPage]["widget"]
		page.set_padding (4, 4)
		self.widgetTree.get_widget ("mainbar").add (page)
		page.show ()

		# Save this page, to remove it before displayed the next page.
		self.oldPage = page

	# Unreferences the main window's widgets.
	def quit (self):
		self.win.destroy ()
